"""
Reading the leaderboards with :class:`SteamLeaderboard` is as easy as iterating over a list.
"""
import logging
from steam.core.msg import MsgProto
from steam.enums import EResult, ELeaderboardDataRequest, ELeaderboardSortMethod, ELeaderboardDisplayType
from steam.enums.emsg import EMsg
from steam.utils import _range, chunks
from steam.utils.throttle import ConstantRateLimit


class Leaderboards(object):
    def __init__(self, *args, **kwargs):
        super(Leaderboards, self).__init__(*args, **kwargs)

    def get_leaderboard(self, app_id, name):
        """.. versionadded:: 0.8.2

        Find a leaderboard

        :param app_id: application id
        :type app_id: :class:`int`
        :param name: leaderboard name
        :type name: :class:`str`
        :return: leaderboard instance
        :rtype: :class:`SteamLeaderboard`
        :raises: :class:`LookupError` on message timeout or error
        """
        message = MsgProto(EMsg.ClientLBSFindOrCreateLB)
        message.header.routing_appid = app_id
        message.body.app_id = app_id
        message.body.leaderboard_name = name
        message.body.create_if_not_found = False

        resp = self.send_job_and_wait(message, timeout=15)

        if not resp:
            raise LookupError("Didn't receive response within 15seconds :(")
        if resp.eresult != EResult.OK:
            raise LookupError(EResult(resp.eresult))

        return SteamLeaderboard(self, app_id, name, resp)


class SteamLeaderboard(object):
    """.. versionadded:: 0.8.2

    Steam leaderboard object.
    Generated via :meth:`Leaderboards.get_leaderboard()`
    Works more or less like a :class:`list` to access entries.

    .. note::
        Each slice will produce a message to steam.
        Steam and protobufs might not like large slices.
        Avoid accessing individual entries by index and instead use iteration or well sized slices.

    Example usage:

    .. code:: python

        lb = client.get_leaderboard(...)

        for entry in lb[:100]:  # top 100
            print entry
    """
    ELeaderboardDataRequest = ELeaderboardDataRequest
    ELeaderboardSortMethod = ELeaderboardSortMethod
    ELeaderboardDisplayType = ELeaderboardDisplayType

    app_id = 0
    name = ''  #: leaderboard name
    id = 0 #: leaderboard id
    entry_count = 0
    sort_method = ELeaderboardSortMethod.NONE      #: :class:`steam.enums.common.ELeaderboardSortMethod`
    display_type = ELeaderboardDisplayType.NONE    #: :class:`steam.enums.common.ELeaderboardDisplayType`
    data_request = ELeaderboardDataRequest.Global  #: :class:`steam.enums.common.ELeaderboardDataRequest`

    def __init__(self, steam, app_id, name, data=None):
        self._steam = steam
        self.app_id = app_id

        if data is not None:
            for field in data.DESCRIPTOR.fields:
                if field.name.startswith('leaderboard_'):
                    self.__dict__[field.name.replace('leaderboard_', '')] = getattr(data, field.name)

        self.sort_method = ELeaderboardSortMethod(self.sort_method)
        self.display_type = ELeaderboardDisplayType(self.display_type)

    def __repr__(self):
        return "<%s(%d, %s, %d, %s, %s)>" % (
            self.__class__.__name__,
            self.app_id,
            repr(self.name),
            len(self),
            self.sort_method,
            self.display_type,
            )

    def __len__(self):
        return self.entry_count

    def get_entries(self, start=0, end=0, data_request=None, steam_ids=None):
        """Get leaderboard entries.

        :param start: start entry, not index (e.g. rank 1 is ``start=1``)
        :type start: :class:`int`
        :param end: end entry, not index (e.g. only one entry then ``start=1,end=1``)
        :type end: :class:`int`
        :param data_request: data being requested
        :type data_request: :class:`steam.enums.common.ELeaderboardDataRequest`
        :param steam_ids: list of steam ids when using :attr:`.ELeaderboardDataRequest.Users`
        :type steamids: :class:`list`
        :return: a list of entries, see ``CMsgClientLBSGetLBEntriesResponse``
        :rtype: :class:`list`
        :raises: :class:`LookupError` on message timeout or error
        """
        message = MsgProto(EMsg.ClientLBSGetLBEntries)
        message.body.app_id = self.app_id
        message.body.leaderboard_id = self.id
        message.body.range_start = start
        message.body.range_end = end
        message.body.leaderboard_data_request = self.data_request if data_request is None else data_request

        if steam_ids:
            message.body.steamids.extend(steam_ids)

        resp = self._steam.send_job_and_wait(message, timeout=15)

        if not resp:
            raise LookupError("Didn't receive response within 15seconds :(")
        if resp.eresult != EResult.OK:
            raise LookupError(EResult(resp.eresult))

        if resp.HasField('leaderboard_entry_count'):
            self.entry_count = resp.leaderboard_entry_count

        return resp.entries

    def __getitem__(self, x):
        if isinstance(x, slice):
            stop_max = len(self)
            start = 0 if x.start is None else x.start if x.start >= 0 else max(0, x.start + stop_max)
            stop = stop_max if x.stop is None else x.stop if x.stop >= 0 else max(0, x.stop + stop_max)
            step = x.step or 1
            if step < 0:
                start, stop = stop, start
            step = abs(step)

            if start >= stop: return []
        else:
            if x < 0: x += self.entry_count
            start, stop, step = x, x + 1, 1

            if x < 0 or x >= self.entry_count:
                raise IndexError('list index out of range')

        entries = self.get_entries(start+1, stop)

        if isinstance(x, slice):
            return [entries[i] for i in _range(0, len(entries), step)]
        else:
            return entries[0]

    def get_iter(self, times, seconds, chunk_size=2000):
        """Make a iterator over the entries

        See :class:`steam.util.throttle.ConstantRateLimit` for ``times`` and ``seconds`` parameters.

        :param chunk_size: number of entries per request
        :type chunk_size: :class:`int`
        :returns: generator object
        :rtype: :class:`generator`

        The iterator essentially buffers ``chuck_size`` number of entries, and ensures
        we are not sending messages too fast.
        For example, the ``__iter__`` method on this class uses ``get_iter(1, 1, 2000)``
        """
        def entry_generator():
            with ConstantRateLimit(times, seconds, sleep_func=self._steam.sleep) as r:
                for entries in chunks(self, chunk_size):
                    if not entries:
                        return
                    for entry in entries:
                        yield entry
                    r.wait()
        return entry_generator()

    def __iter__(self):
        return self.get_iter(1, 1, 2000)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_gameservers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_gameservers.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,steammessages_clientserver_gameservers.proto\x1a\x18steammessages_base.proto\"\xed\x01\n\x10\x43MsgGSServerType\x12\x15\n\rapp_id_served\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\"\n\x1a\x64\x65precated_game_ip_address\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\x10\n\x08game_dir\x18\x05 \x01(\t\x12\x14\n\x0cgame_version\x18\x06 \x01(\t\x12\x17\n\x0fgame_query_port\x18\x07 \x01(\r\x12\x17\n\x0fgame_port_local\x18\n \x01(\r\x12\x11\n\tsdr_logon\x18\x08 \x01(\x0c\x12\x0f\n\x07\x66\x61ke_ip\x18\t \x01(\x07\"&\n\x11\x43MsgGSStatusReply\x12\x11\n\tis_secure\x18\x01 \x01(\x08\"\xa9\x01\n\x10\x43MsgGSPlayerList\x12)\n\x07players\x18\x01 \x03(\x0b\x32\x18.CMsgGSPlayerList.Player\x1aj\n\x06Player\x12\x10\n\x08steam_id\x18\x01 \x01(\x04\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\x0c\x12!\n\tpublic_ip\x18\x04 \x01(\x0b\x32\x0e.CMsgIPAddress\"u\n\x11\x43MsgGSUserPlaying\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\x0c\x12!\n\tpublic_ip\x18\x04 \x01(\x0b\x32\x0e.CMsgIPAddress\"*\n\x16\x43MsgGSDisconnectNotice\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"\x97\x04\n\x12\x43MsgGameServerData\x12\x10\n\x08revision\x18\x18 \x01(\r\x12\x12\n\nquery_port\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\x16\n\x0espectator_port\x18\x05 \x01(\r\x12\x13\n\x0bserver_name\x18\x16 \x01(\t\x12\x18\n\x10game_description\x18\x1d \x01(\t\x12\x1d\n\x15spectator_server_name\x18\x1b \x01(\t\x12\x0f\n\x07\x66\x61ke_ip\x18\x1c \x01(\x07\x12\x19\n\x11sdr_ping_location\x18\x1e \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x06 \x01(\r\x12\x0f\n\x07gamedir\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x0f\n\x07product\x18\t \x01(\t\x12\x0e\n\x06region\x18\n \x01(\t\x12+\n\x07players\x18\x0b \x03(\x0b\x32\x1a.CMsgGameServerData.Player\x12\x13\n\x0bmax_players\x18\x0c \x01(\r\x12\x11\n\tbot_count\x18\r \x01(\r\x12\x10\n\x08password\x18\x0e \x01(\x08\x12\x0e\n\x06secure\x18\x0f \x01(\x08\x12\x11\n\tdedicated\x18\x10 \x01(\x08\x12\n\n\x02os\x18\x11 \x01(\t\x12\x11\n\tgame_data\x18\x12 \x01(\t\x12\x11\n\tgame_type\x18\x14 \x01(\t\x12\x0b\n\x03map\x18\x15 \x01(\t\x1a\x1a\n\x06Player\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"M\n\x14\x43MsgGameServerRemove\x12\x1a\n\x12legacy_steam_id_gs\x18\x01 \x01(\x06\x12\x19\n\x11legacy_query_port\x18\x03 \x01(\r\"\x82\x01\n\x18\x43MsgClientGMSServerQuery\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x17\n\x0fgeo_location_ip\x18\x02 \x01(\r\x12\x13\n\x0bregion_code\x18\x03 \x01(\r\x12\x13\n\x0b\x66ilter_text\x18\x04 \x01(\t\x12\x13\n\x0bmax_servers\x18\x05 \x01(\r\"\xa5\x07\n CMsgGMSClientServerQueryResponse\x12\x39\n\x07servers\x18\x01 \x03(\x0b\x32(.CMsgGMSClientServerQueryResponse.Server\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x45\n\x13\x64\x65\x66\x61ult_server_data\x18\x03 \x01(\x0b\x32(.CMsgGMSClientServerQueryResponse.Server\x12\x16\n\x0eserver_strings\x18\x04 \x03(\t\x1a\xa0\x05\n\x06Server\x12\x1c\n\x14\x64\x65precated_server_ip\x18\x01 \x01(\r\x12\x12\n\nquery_port\x18\x02 \x01(\r\x12\x14\n\x0c\x61uth_players\x18\x03 \x01(\r\x12!\n\tserver_ip\x18\x04 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x10\n\x08steam_id\x18\x06 \x01(\x06\x12\x10\n\x08revision\x18\x07 \x01(\r\x12\x0f\n\x07players\x18\x08 \x01(\r\x12\x11\n\tgame_port\x18\t \x01(\r\x12\x11\n\tsdr_popid\x18\n \x01(\x07\x12\x19\n\x11sdr_ping_location\x18  \x01(\t\x12\r\n\x05\x66lags\x18\x0b \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x0c \x01(\r\x12\x13\n\x0bmax_players\x18\r \x01(\r\x12\x0c\n\x04\x62ots\x18\x0e \x01(\r\x12\x16\n\x0espectator_port\x18\x0f \x01(\r\x12\x13\n\x0bgamedir_str\x18\x10 \x01(\t\x12\x18\n\x10gamedir_strindex\x18\x11 \x01(\r\x12\x0f\n\x07map_str\x18\x12 \x01(\t\x12\x14\n\x0cmap_strindex\x18\x13 \x01(\r\x12\x10\n\x08name_str\x18\x14 \x01(\t\x12\x15\n\rname_strindex\x18\x15 \x01(\r\x12\x1c\n\x14game_description_str\x18\x16 \x01(\t\x12!\n\x19game_description_strindex\x18\x17 \x01(\r\x12\x13\n\x0bversion_str\x18\x18 \x01(\t\x12\x18\n\x10version_strindex\x18\x19 \x01(\r\x12\x14\n\x0cgametype_str\x18\x1a \x01(\t\x12\x19\n\x11gametype_strindex\x18\x1b \x01(\r\x12\x1a\n\x12spectator_name_str\x18\x1e \x01(\t\x12\x1f\n\x17spectator_name_strindex\x18\x1f \x01(\r\"5\n\x06\x45\x46lags\x12\x17\n\x13k_EFlag_HasPassword\x10\x01\x12\x12\n\x0ek_EFlag_Secure\x10\x02\"O\n\x17\x43MsgGameServerOutOfDate\x12\x13\n\x0bsteam_id_gs\x18\x01 \x01(\x06\x12\x0e\n\x06reject\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\t\"0\n\x17\x43MsgGSAssociateWithClan\x12\x15\n\rsteam_id_clan\x18\x01 \x01(\x06\"L\n\x1f\x43MsgGSAssociateWithClanResponse\x12\x15\n\rsteam_id_clan\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\"A\n#CMsgGSComputeNewPlayerCompatibility\x12\x1a\n\x12steam_id_candidate\x18\x01 \x01(\x06\"\xcf\x01\n+CMsgGSComputeNewPlayerCompatibilityResponse\x12\x1a\n\x12steam_id_candidate\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12\x16\n\x0eis_clan_member\x18\x03 \x01(\x08\x12\x18\n\x10\x63t_dont_like_you\x18\x04 \x01(\x05\x12\x18\n\x10\x63t_you_dont_like\x18\x05 \x01(\x05\x12$\n\x1c\x63t_clanmembers_dont_like_you\x18\x06 \x01(\x05\x42\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])



_CMSGGMSCLIENTSERVERQUERYRESPONSE_EFLAGS = _descriptor.EnumDescriptor(
  name='EFlags',
  full_name='CMsgGMSClientServerQueryResponse.EFlags',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EFlag_HasPassword', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFlag_Secure', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2320,
  serialized_end=2373,
)
_sym_db.RegisterEnumDescriptor(_CMSGGMSCLIENTSERVERQUERYRESPONSE_EFLAGS)


_CMSGGSSERVERTYPE = _descriptor.Descriptor(
  name='CMsgGSServerType',
  full_name='CMsgGSServerType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id_served', full_name='CMsgGSServerType.app_id_served', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CMsgGSServerType.flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_game_ip_address', full_name='CMsgGSServerType.deprecated_game_ip_address', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_port', full_name='CMsgGSServerType.game_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_dir', full_name='CMsgGSServerType.game_dir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_version', full_name='CMsgGSServerType.game_version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_query_port', full_name='CMsgGSServerType.game_query_port', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_port_local', full_name='CMsgGSServerType.game_port_local', index=7,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdr_logon', full_name='CMsgGSServerType.sdr_logon', index=8,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fake_ip', full_name='CMsgGSServerType.fake_ip', index=9,
      number=9, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=312,
)


_CMSGGSSTATUSREPLY = _descriptor.Descriptor(
  name='CMsgGSStatusReply',
  full_name='CMsgGSStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_secure', full_name='CMsgGSStatusReply.is_secure', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=352,
)


_CMSGGSPLAYERLIST_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CMsgGSPlayerList.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSPlayerList.Player.steam_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_public_ip', full_name='CMsgGSPlayerList.Player.deprecated_public_ip', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgGSPlayerList.Player.token', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CMsgGSPlayerList.Player.public_ip', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=524,
)

_CMSGGSPLAYERLIST = _descriptor.Descriptor(
  name='CMsgGSPlayerList',
  full_name='CMsgGSPlayerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgGSPlayerList.players', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGSPLAYERLIST_PLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=524,
)


_CMSGGSUSERPLAYING = _descriptor.Descriptor(
  name='CMsgGSUserPlaying',
  full_name='CMsgGSUserPlaying',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSUserPlaying.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_public_ip', full_name='CMsgGSUserPlaying.deprecated_public_ip', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgGSUserPlaying.token', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CMsgGSUserPlaying.public_ip', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=643,
)


_CMSGGSDISCONNECTNOTICE = _descriptor.Descriptor(
  name='CMsgGSDisconnectNotice',
  full_name='CMsgGSDisconnectNotice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSDisconnectNotice.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=687,
)


_CMSGGAMESERVERDATA_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CMsgGameServerData.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGameServerData.Player.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1199,
  serialized_end=1225,
)

_CMSGGAMESERVERDATA = _descriptor.Descriptor(
  name='CMsgGameServerData',
  full_name='CMsgGameServerData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='revision', full_name='CMsgGameServerData.revision', index=0,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_port', full_name='CMsgGameServerData.query_port', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_port', full_name='CMsgGameServerData.game_port', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spectator_port', full_name='CMsgGameServerData.spectator_port', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_name', full_name='CMsgGameServerData.server_name', index=4,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_description', full_name='CMsgGameServerData.game_description', index=5,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spectator_server_name', full_name='CMsgGameServerData.spectator_server_name', index=6,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fake_ip', full_name='CMsgGameServerData.fake_ip', index=7,
      number=28, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdr_ping_location', full_name='CMsgGameServerData.sdr_ping_location', index=8,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgGameServerData.app_id', index=9,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gamedir', full_name='CMsgGameServerData.gamedir', index=10,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgGameServerData.version', index=11,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='CMsgGameServerData.product', index=12,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='CMsgGameServerData.region', index=13,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgGameServerData.players', index=14,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_players', full_name='CMsgGameServerData.max_players', index=15,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_count', full_name='CMsgGameServerData.bot_count', index=16,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgGameServerData.password', index=17,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secure', full_name='CMsgGameServerData.secure', index=18,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dedicated', full_name='CMsgGameServerData.dedicated', index=19,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os', full_name='CMsgGameServerData.os', index=20,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_data', full_name='CMsgGameServerData.game_data', index=21,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_type', full_name='CMsgGameServerData.game_type', index=22,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map', full_name='CMsgGameServerData.map', index=23,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGAMESERVERDATA_PLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=690,
  serialized_end=1225,
)


_CMSGGAMESERVERREMOVE = _descriptor.Descriptor(
  name='CMsgGameServerRemove',
  full_name='CMsgGameServerRemove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='legacy_steam_id_gs', full_name='CMsgGameServerRemove.legacy_steam_id_gs', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legacy_query_port', full_name='CMsgGameServerRemove.legacy_query_port', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1227,
  serialized_end=1304,
)


_CMSGCLIENTGMSSERVERQUERY = _descriptor.Descriptor(
  name='CMsgClientGMSServerQuery',
  full_name='CMsgClientGMSServerQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientGMSServerQuery.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_location_ip', full_name='CMsgClientGMSServerQuery.geo_location_ip', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region_code', full_name='CMsgClientGMSServerQuery.region_code', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_text', full_name='CMsgClientGMSServerQuery.filter_text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_servers', full_name='CMsgClientGMSServerQuery.max_servers', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1437,
)


_CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='CMsgGMSClientServerQueryResponse.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deprecated_server_ip', full_name='CMsgGMSClientServerQueryResponse.Server.deprecated_server_ip', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_port', full_name='CMsgGMSClientServerQueryResponse.Server.query_port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_players', full_name='CMsgGMSClientServerQueryResponse.Server.auth_players', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_ip', full_name='CMsgGMSClientServerQueryResponse.Server.server_ip', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGMSClientServerQueryResponse.Server.steam_id', index=4,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='CMsgGMSClientServerQueryResponse.Server.revision', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgGMSClientServerQueryResponse.Server.players', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_port', full_name='CMsgGMSClientServerQueryResponse.Server.game_port', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdr_popid', full_name='CMsgGMSClientServerQueryResponse.Server.sdr_popid', index=8,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdr_ping_location', full_name='CMsgGMSClientServerQueryResponse.Server.sdr_ping_location', index=9,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CMsgGMSClientServerQueryResponse.Server.flags', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgGMSClientServerQueryResponse.Server.app_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_players', full_name='CMsgGMSClientServerQueryResponse.Server.max_players', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bots', full_name='CMsgGMSClientServerQueryResponse.Server.bots', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spectator_port', full_name='CMsgGMSClientServerQueryResponse.Server.spectator_port', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gamedir_str', full_name='CMsgGMSClientServerQueryResponse.Server.gamedir_str', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gamedir_strindex', full_name='CMsgGMSClientServerQueryResponse.Server.gamedir_strindex', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_str', full_name='CMsgGMSClientServerQueryResponse.Server.map_str', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_strindex', full_name='CMsgGMSClientServerQueryResponse.Server.map_strindex', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_str', full_name='CMsgGMSClientServerQueryResponse.Server.name_str', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_strindex', full_name='CMsgGMSClientServerQueryResponse.Server.name_strindex', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_description_str', full_name='CMsgGMSClientServerQueryResponse.Server.game_description_str', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_description_strindex', full_name='CMsgGMSClientServerQueryResponse.Server.game_description_strindex', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_str', full_name='CMsgGMSClientServerQueryResponse.Server.version_str', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_strindex', full_name='CMsgGMSClientServerQueryResponse.Server.version_strindex', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gametype_str', full_name='CMsgGMSClientServerQueryResponse.Server.gametype_str', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gametype_strindex', full_name='CMsgGMSClientServerQueryResponse.Server.gametype_strindex', index=26,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spectator_name_str', full_name='CMsgGMSClientServerQueryResponse.Server.spectator_name_str', index=27,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spectator_name_strindex', full_name='CMsgGMSClientServerQueryResponse.Server.spectator_name_strindex', index=28,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1646,
  serialized_end=2318,
)

_CMSGGMSCLIENTSERVERQUERYRESPONSE = _descriptor.Descriptor(
  name='CMsgGMSClientServerQueryResponse',
  full_name='CMsgGMSClientServerQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='CMsgGMSClientServerQueryResponse.servers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='CMsgGMSClientServerQueryResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_server_data', full_name='CMsgGMSClientServerQueryResponse.default_server_data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_strings', full_name='CMsgGMSClientServerQueryResponse.server_strings', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER, ],
  enum_types=[
    _CMSGGMSCLIENTSERVERQUERYRESPONSE_EFLAGS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=2373,
)


_CMSGGAMESERVEROUTOFDATE = _descriptor.Descriptor(
  name='CMsgGameServerOutOfDate',
  full_name='CMsgGameServerOutOfDate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_gs', full_name='CMsgGameServerOutOfDate.steam_id_gs', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reject', full_name='CMsgGameServerOutOfDate.reject', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgGameServerOutOfDate.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2375,
  serialized_end=2454,
)


_CMSGGSASSOCIATEWITHCLAN = _descriptor.Descriptor(
  name='CMsgGSAssociateWithClan',
  full_name='CMsgGSAssociateWithClan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_clan', full_name='CMsgGSAssociateWithClan.steam_id_clan', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2456,
  serialized_end=2504,
)


_CMSGGSASSOCIATEWITHCLANRESPONSE = _descriptor.Descriptor(
  name='CMsgGSAssociateWithClanResponse',
  full_name='CMsgGSAssociateWithClanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_clan', full_name='CMsgGSAssociateWithClanResponse.steam_id_clan', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgGSAssociateWithClanResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2506,
  serialized_end=2582,
)


_CMSGGSCOMPUTENEWPLAYERCOMPATIBILITY = _descriptor.Descriptor(
  name='CMsgGSComputeNewPlayerCompatibility',
  full_name='CMsgGSComputeNewPlayerCompatibility',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_candidate', full_name='CMsgGSComputeNewPlayerCompatibility.steam_id_candidate', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2584,
  serialized_end=2649,
)


_CMSGGSCOMPUTENEWPLAYERCOMPATIBILITYRESPONSE = _descriptor.Descriptor(
  name='CMsgGSComputeNewPlayerCompatibilityResponse',
  full_name='CMsgGSComputeNewPlayerCompatibilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_candidate', full_name='CMsgGSComputeNewPlayerCompatibilityResponse.steam_id_candidate', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgGSComputeNewPlayerCompatibilityResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_clan_member', full_name='CMsgGSComputeNewPlayerCompatibilityResponse.is_clan_member', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ct_dont_like_you', full_name='CMsgGSComputeNewPlayerCompatibilityResponse.ct_dont_like_you', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ct_you_dont_like', full_name='CMsgGSComputeNewPlayerCompatibilityResponse.ct_you_dont_like', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ct_clanmembers_dont_like_you', full_name='CMsgGSComputeNewPlayerCompatibilityResponse.ct_clanmembers_dont_like_you', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2652,
  serialized_end=2859,
)

_CMSGGSPLAYERLIST_PLAYER.fields_by_name['public_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGGSPLAYERLIST_PLAYER.containing_type = _CMSGGSPLAYERLIST
_CMSGGSPLAYERLIST.fields_by_name['players'].message_type = _CMSGGSPLAYERLIST_PLAYER
_CMSGGSUSERPLAYING.fields_by_name['public_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGGAMESERVERDATA_PLAYER.containing_type = _CMSGGAMESERVERDATA
_CMSGGAMESERVERDATA.fields_by_name['players'].message_type = _CMSGGAMESERVERDATA_PLAYER
_CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER.fields_by_name['server_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER.containing_type = _CMSGGMSCLIENTSERVERQUERYRESPONSE
_CMSGGMSCLIENTSERVERQUERYRESPONSE.fields_by_name['servers'].message_type = _CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER
_CMSGGMSCLIENTSERVERQUERYRESPONSE.fields_by_name['default_server_data'].message_type = _CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER
_CMSGGMSCLIENTSERVERQUERYRESPONSE_EFLAGS.containing_type = _CMSGGMSCLIENTSERVERQUERYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGSServerType'] = _CMSGGSSERVERTYPE
DESCRIPTOR.message_types_by_name['CMsgGSStatusReply'] = _CMSGGSSTATUSREPLY
DESCRIPTOR.message_types_by_name['CMsgGSPlayerList'] = _CMSGGSPLAYERLIST
DESCRIPTOR.message_types_by_name['CMsgGSUserPlaying'] = _CMSGGSUSERPLAYING
DESCRIPTOR.message_types_by_name['CMsgGSDisconnectNotice'] = _CMSGGSDISCONNECTNOTICE
DESCRIPTOR.message_types_by_name['CMsgGameServerData'] = _CMSGGAMESERVERDATA
DESCRIPTOR.message_types_by_name['CMsgGameServerRemove'] = _CMSGGAMESERVERREMOVE
DESCRIPTOR.message_types_by_name['CMsgClientGMSServerQuery'] = _CMSGCLIENTGMSSERVERQUERY
DESCRIPTOR.message_types_by_name['CMsgGMSClientServerQueryResponse'] = _CMSGGMSCLIENTSERVERQUERYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGameServerOutOfDate'] = _CMSGGAMESERVEROUTOFDATE
DESCRIPTOR.message_types_by_name['CMsgGSAssociateWithClan'] = _CMSGGSASSOCIATEWITHCLAN
DESCRIPTOR.message_types_by_name['CMsgGSAssociateWithClanResponse'] = _CMSGGSASSOCIATEWITHCLANRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGSComputeNewPlayerCompatibility'] = _CMSGGSCOMPUTENEWPLAYERCOMPATIBILITY
DESCRIPTOR.message_types_by_name['CMsgGSComputeNewPlayerCompatibilityResponse'] = _CMSGGSCOMPUTENEWPLAYERCOMPATIBILITYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgGSServerType = _reflection.GeneratedProtocolMessageType('CMsgGSServerType', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSSERVERTYPE,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSServerType)
  })
_sym_db.RegisterMessage(CMsgGSServerType)

CMsgGSStatusReply = _reflection.GeneratedProtocolMessageType('CMsgGSStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSSTATUSREPLY,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSStatusReply)
  })
_sym_db.RegisterMessage(CMsgGSStatusReply)

CMsgGSPlayerList = _reflection.GeneratedProtocolMessageType('CMsgGSPlayerList', (_message.Message,), {

  'Player' : _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), {
    'DESCRIPTOR' : _CMSGGSPLAYERLIST_PLAYER,
    '__module__' : 'steammessages_clientserver_gameservers_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGSPlayerList.Player)
    })
  ,
  'DESCRIPTOR' : _CMSGGSPLAYERLIST,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSPlayerList)
  })
_sym_db.RegisterMessage(CMsgGSPlayerList)
_sym_db.RegisterMessage(CMsgGSPlayerList.Player)

CMsgGSUserPlaying = _reflection.GeneratedProtocolMessageType('CMsgGSUserPlaying', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSUSERPLAYING,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSUserPlaying)
  })
_sym_db.RegisterMessage(CMsgGSUserPlaying)

CMsgGSDisconnectNotice = _reflection.GeneratedProtocolMessageType('CMsgGSDisconnectNotice', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSDISCONNECTNOTICE,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSDisconnectNotice)
  })
_sym_db.RegisterMessage(CMsgGSDisconnectNotice)

CMsgGameServerData = _reflection.GeneratedProtocolMessageType('CMsgGameServerData', (_message.Message,), {

  'Player' : _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), {
    'DESCRIPTOR' : _CMSGGAMESERVERDATA_PLAYER,
    '__module__' : 'steammessages_clientserver_gameservers_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGameServerData.Player)
    })
  ,
  'DESCRIPTOR' : _CMSGGAMESERVERDATA,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerData)
  })
_sym_db.RegisterMessage(CMsgGameServerData)
_sym_db.RegisterMessage(CMsgGameServerData.Player)

CMsgGameServerRemove = _reflection.GeneratedProtocolMessageType('CMsgGameServerRemove', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGAMESERVERREMOVE,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerRemove)
  })
_sym_db.RegisterMessage(CMsgGameServerRemove)

CMsgClientGMSServerQuery = _reflection.GeneratedProtocolMessageType('CMsgClientGMSServerQuery', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGMSSERVERQUERY,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGMSServerQuery)
  })
_sym_db.RegisterMessage(CMsgClientGMSServerQuery)

CMsgGMSClientServerQueryResponse = _reflection.GeneratedProtocolMessageType('CMsgGMSClientServerQueryResponse', (_message.Message,), {

  'Server' : _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {
    'DESCRIPTOR' : _CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER,
    '__module__' : 'steammessages_clientserver_gameservers_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGMSClientServerQueryResponse.Server)
    })
  ,
  'DESCRIPTOR' : _CMSGGMSCLIENTSERVERQUERYRESPONSE,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGMSClientServerQueryResponse)
  })
_sym_db.RegisterMessage(CMsgGMSClientServerQueryResponse)
_sym_db.RegisterMessage(CMsgGMSClientServerQueryResponse.Server)

CMsgGameServerOutOfDate = _reflection.GeneratedProtocolMessageType('CMsgGameServerOutOfDate', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGAMESERVEROUTOFDATE,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerOutOfDate)
  })
_sym_db.RegisterMessage(CMsgGameServerOutOfDate)

CMsgGSAssociateWithClan = _reflection.GeneratedProtocolMessageType('CMsgGSAssociateWithClan', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSASSOCIATEWITHCLAN,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSAssociateWithClan)
  })
_sym_db.RegisterMessage(CMsgGSAssociateWithClan)

CMsgGSAssociateWithClanResponse = _reflection.GeneratedProtocolMessageType('CMsgGSAssociateWithClanResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSASSOCIATEWITHCLANRESPONSE,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSAssociateWithClanResponse)
  })
_sym_db.RegisterMessage(CMsgGSAssociateWithClanResponse)

CMsgGSComputeNewPlayerCompatibility = _reflection.GeneratedProtocolMessageType('CMsgGSComputeNewPlayerCompatibility', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSCOMPUTENEWPLAYERCOMPATIBILITY,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSComputeNewPlayerCompatibility)
  })
_sym_db.RegisterMessage(CMsgGSComputeNewPlayerCompatibility)

CMsgGSComputeNewPlayerCompatibilityResponse = _reflection.GeneratedProtocolMessageType('CMsgGSComputeNewPlayerCompatibilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSCOMPUTENEWPLAYERCOMPATIBILITYRESPONSE,
  '__module__' : 'steammessages_clientserver_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSComputeNewPlayerCompatibilityResponse)
  })
_sym_db.RegisterMessage(CMsgGSComputeNewPlayerCompatibilityResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_secrets.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_secrets.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bsteammessages_secrets.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x9b\x01\n\x12\x43KeyEscrow_Request\x12\x1b\n\x13rsa_oaep_sha_ticket\x18\x01 \x01(\x0c\x12\x10\n\x08password\x18\x02 \x01(\x0c\x12\x41\n\x05usage\x18\x03 \x01(\x0e\x32\x10.EKeyEscrowUsage: k_EKeyEscrowUsageStreamingDevice\x12\x13\n\x0b\x64\x65vice_name\x18\x04 \x01(\t\"\x82\x02\n\x11\x43KeyEscrow_Ticket\x12\x10\n\x08password\x18\x01 \x01(\x0c\x12\x12\n\nidentifier\x18\x02 \x01(\x04\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\r\x12\x41\n\x05usage\x18\x05 \x01(\x0e\x32\x10.EKeyEscrowUsage: k_EKeyEscrowUsageStreamingDevice\x12\x13\n\x0b\x64\x65vice_name\x18\x06 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x07 \x01(\t\x12\x15\n\rdevice_serial\x18\x08 \x01(\t\x12\x1e\n\x16\x64\x65vice_provisioning_id\x18\t \x01(\r\"9\n\x13\x43KeyEscrow_Response\x12\"\n\x06ticket\x18\x01 \x01(\x0b\x32\x12.CKeyEscrow_Ticket*7\n\x0f\x45KeyEscrowUsage\x12$\n k_EKeyEscrowUsageStreamingDevice\x10\x00\x32\xc8\x01\n\x07Secrets\x12\x80\x01\n\tKeyEscrow\x12\x13.CKeyEscrow_Request\x1a\x14.CKeyEscrow_Response\"H\x82\xb5\x18\x44Service to perform authenticated key-exchange involving Steam Client\x1a:\x82\xb5\x18\x36Service for accessing credentials and guarding secretsB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_EKEYESCROWUSAGE = _descriptor.EnumDescriptor(
  name='EKeyEscrowUsage',
  full_name='EKeyEscrowUsage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EKeyEscrowUsageStreamingDevice', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=569,
  serialized_end=624,
)
_sym_db.RegisterEnumDescriptor(_EKEYESCROWUSAGE)

EKeyEscrowUsage = enum_type_wrapper.EnumTypeWrapper(_EKEYESCROWUSAGE)
k_EKeyEscrowUsageStreamingDevice = 0



_CKEYESCROW_REQUEST = _descriptor.Descriptor(
  name='CKeyEscrow_Request',
  full_name='CKeyEscrow_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rsa_oaep_sha_ticket', full_name='CKeyEscrow_Request.rsa_oaep_sha_ticket', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='CKeyEscrow_Request.password', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='CKeyEscrow_Request.usage', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='CKeyEscrow_Request.device_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=247,
)


_CKEYESCROW_TICKET = _descriptor.Descriptor(
  name='CKeyEscrow_Ticket',
  full_name='CKeyEscrow_Ticket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='CKeyEscrow_Ticket.password', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='CKeyEscrow_Ticket.identifier', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='CKeyEscrow_Ticket.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CKeyEscrow_Ticket.timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='CKeyEscrow_Ticket.usage', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='CKeyEscrow_Ticket.device_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_model', full_name='CKeyEscrow_Ticket.device_model', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_serial', full_name='CKeyEscrow_Ticket.device_serial', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_provisioning_id', full_name='CKeyEscrow_Ticket.device_provisioning_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=508,
)


_CKEYESCROW_RESPONSE = _descriptor.Descriptor(
  name='CKeyEscrow_Response',
  full_name='CKeyEscrow_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CKeyEscrow_Response.ticket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=567,
)

_CKEYESCROW_REQUEST.fields_by_name['usage'].enum_type = _EKEYESCROWUSAGE
_CKEYESCROW_TICKET.fields_by_name['usage'].enum_type = _EKEYESCROWUSAGE
_CKEYESCROW_RESPONSE.fields_by_name['ticket'].message_type = _CKEYESCROW_TICKET
DESCRIPTOR.message_types_by_name['CKeyEscrow_Request'] = _CKEYESCROW_REQUEST
DESCRIPTOR.message_types_by_name['CKeyEscrow_Ticket'] = _CKEYESCROW_TICKET
DESCRIPTOR.message_types_by_name['CKeyEscrow_Response'] = _CKEYESCROW_RESPONSE
DESCRIPTOR.enum_types_by_name['EKeyEscrowUsage'] = _EKEYESCROWUSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CKeyEscrow_Request = _reflection.GeneratedProtocolMessageType('CKeyEscrow_Request', (_message.Message,), {
  'DESCRIPTOR' : _CKEYESCROW_REQUEST,
  '__module__' : 'steammessages_secrets_pb2'
  # @@protoc_insertion_point(class_scope:CKeyEscrow_Request)
  })
_sym_db.RegisterMessage(CKeyEscrow_Request)

CKeyEscrow_Ticket = _reflection.GeneratedProtocolMessageType('CKeyEscrow_Ticket', (_message.Message,), {
  'DESCRIPTOR' : _CKEYESCROW_TICKET,
  '__module__' : 'steammessages_secrets_pb2'
  # @@protoc_insertion_point(class_scope:CKeyEscrow_Ticket)
  })
_sym_db.RegisterMessage(CKeyEscrow_Ticket)

CKeyEscrow_Response = _reflection.GeneratedProtocolMessageType('CKeyEscrow_Response', (_message.Message,), {
  'DESCRIPTOR' : _CKEYESCROW_RESPONSE,
  '__module__' : 'steammessages_secrets_pb2'
  # @@protoc_insertion_point(class_scope:CKeyEscrow_Response)
  })
_sym_db.RegisterMessage(CKeyEscrow_Response)


DESCRIPTOR._options = None

_SECRETS = _descriptor.ServiceDescriptor(
  name='Secrets',
  full_name='Secrets',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\0306Service for accessing credentials and guarding secrets',
  create_key=_descriptor._internal_create_key,
  serialized_start=627,
  serialized_end=827,
  methods=[
  _descriptor.MethodDescriptor(
    name='KeyEscrow',
    full_name='Secrets.KeyEscrow',
    index=0,
    containing_service=None,
    input_type=_CKEYESCROW_REQUEST,
    output_type=_CKEYESCROW_RESPONSE,
    serialized_options=b'\202\265\030DService to perform authenticated key-exchange involving Steam Client',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SECRETS)

DESCRIPTOR.services_by_name['Secrets'] = _SECRETS

Secrets = service_reflection.GeneratedServiceType('Secrets', (_service.Service,), dict(
  DESCRIPTOR = _SECRETS,
  __module__ = 'steammessages_secrets_pb2'
  ))

Secrets_Stub = service_reflection.GeneratedServiceStubType('Secrets_Stub', (Secrets,), dict(
  DESCRIPTOR = _SECRETS,
  __module__ = 'steammessages_secrets_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_linkfilter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_linkfilter.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1esteammessages_linkfilter.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x9d\x02\n,CCommunity_GetLinkFilterHashPrefixes_Request\x12G\n\x08hit_type\x18\x01 \x01(\rB5\x82\xb5\x18\x31The retrieved hits will be filtered to this type.\x12\\\n\x05\x63ount\x18\x02 \x01(\rBM\x82\xb5\x18IThe number of hits to retrieve in a single batch. Specify 0 for no limit.\x12\x46\n\x05start\x18\x03 \x01(\x04\x42\x37\x82\xb5\x18\x33The starting count when retrieving hits in batches.\"\x87\x01\n-CCommunity_GetLinkFilterHashPrefixes_Response\x12V\n\rhash_prefixes\x18\x01 \x03(\rB?\x82\xb5\x18;The first 32 bits of the SHA1 hashes of each hit requested.\"\x97\x02\n&CCommunity_GetLinkFilterHashes_Request\x12G\n\x08hit_type\x18\x01 \x01(\rB5\x82\xb5\x18\x31The retrieved hits will be filtered to this type.\x12\\\n\x05\x63ount\x18\x02 \x01(\rBM\x82\xb5\x18IThe number of hits to retrieve in a single batch. Specify 0 for no limit.\x12\x46\n\x05start\x18\x03 \x01(\x04\x42\x37\x82\xb5\x18\x33The starting count when retrieving hits in batches.\"j\n\'CCommunity_GetLinkFilterHashes_Response\x12?\n\x06hashes\x18\x01 \x03(\x0c\x42/\x82\xb5\x18+A list of hashes returned from our request.\"\x80\x01\n+CCommunity_GetLinkFilterListVersion_Request\x12Q\n\x08hit_type\x18\x01 \x01(\rB?\x82\xb5\x18;The version hashes for this type\'s chunks will be returned.\"\xaa\x01\n,CCommunity_GetLinkFilterListVersion_Response\x12\x46\n\x07version\x18\x01 \x01(\tB5\x82\xb5\x18\x31\x41 hash built using the IDs of the contained hits.\x12\x32\n\x05\x63ount\x18\x02 \x01(\x04\x42#\x82\xb5\x18\x1fThe number of hits of this type2\xc6\x05\n\x13\x43ommunityLinkFilter\x12\xd2\x01\n\x19GetLinkFilterHashPrefixes\x12-.CCommunity_GetLinkFilterHashPrefixes_Request\x1a..CCommunity_GetLinkFilterHashPrefixes_Response\"V\x82\xb5\x18RGet a list of hash prefixes for the specified hit type, to use for client caching.\x12\xb9\x01\n\x13GetLinkFilterHashes\x12\'.CCommunity_GetLinkFilterHashes_Request\x1a(.CCommunity_GetLinkFilterHashes_Response\"O\x82\xb5\x18KGet a list of hashes for the specified hit type, to use for client caching.\x12\xcd\x01\n\x18GetLinkFilterListVersion\x12,.CCommunity_GetLinkFilterListVersion_Request\x1a-.CCommunity_GetLinkFilterListVersion_Response\"T\x82\xb5\x18PGet a list of hashes describing the version of each chunk of the requested size.\x1aN\x82\xb5\x18JA service for recording data about Steam Community phishing link filteringB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetLinkFilterHashPrefixes_Request',
  full_name='CCommunity_GetLinkFilterHashPrefixes_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hit_type', full_name='CCommunity_GetLinkFilterHashPrefixes_Request.hit_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301The retrieved hits will be filtered to this type.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_GetLinkFilterHashPrefixes_Request.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030IThe number of hits to retrieve in a single batch. Specify 0 for no limit.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='CCommunity_GetLinkFilterHashPrefixes_Request.start', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303The starting count when retrieving hits in batches.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=380,
)


_CCOMMUNITY_GETLINKFILTERHASHPREFIXES_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetLinkFilterHashPrefixes_Response',
  full_name='CCommunity_GetLinkFilterHashPrefixes_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash_prefixes', full_name='CCommunity_GetLinkFilterHashPrefixes_Response.hash_prefixes', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030;The first 32 bits of the SHA1 hashes of each hit requested.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=518,
)


_CCOMMUNITY_GETLINKFILTERHASHES_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetLinkFilterHashes_Request',
  full_name='CCommunity_GetLinkFilterHashes_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hit_type', full_name='CCommunity_GetLinkFilterHashes_Request.hit_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301The retrieved hits will be filtered to this type.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_GetLinkFilterHashes_Request.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030IThe number of hits to retrieve in a single batch. Specify 0 for no limit.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='CCommunity_GetLinkFilterHashes_Request.start', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303The starting count when retrieving hits in batches.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=800,
)


_CCOMMUNITY_GETLINKFILTERHASHES_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetLinkFilterHashes_Response',
  full_name='CCommunity_GetLinkFilterHashes_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hashes', full_name='CCommunity_GetLinkFilterHashes_Response.hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+A list of hashes returned from our request.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=802,
  serialized_end=908,
)


_CCOMMUNITY_GETLINKFILTERLISTVERSION_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetLinkFilterListVersion_Request',
  full_name='CCommunity_GetLinkFilterListVersion_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hit_type', full_name='CCommunity_GetLinkFilterListVersion_Request.hit_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030;The version hashes for this type\'s chunks will be returned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=911,
  serialized_end=1039,
)


_CCOMMUNITY_GETLINKFILTERLISTVERSION_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetLinkFilterListVersion_Response',
  full_name='CCommunity_GetLinkFilterListVersion_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CCommunity_GetLinkFilterListVersion_Response.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301A hash built using the IDs of the contained hits.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_GetLinkFilterListVersion_Response.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037The number of hits of this type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1212,
)

DESCRIPTOR.message_types_by_name['CCommunity_GetLinkFilterHashPrefixes_Request'] = _CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetLinkFilterHashPrefixes_Response'] = _CCOMMUNITY_GETLINKFILTERHASHPREFIXES_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetLinkFilterHashes_Request'] = _CCOMMUNITY_GETLINKFILTERHASHES_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetLinkFilterHashes_Response'] = _CCOMMUNITY_GETLINKFILTERHASHES_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetLinkFilterListVersion_Request'] = _CCOMMUNITY_GETLINKFILTERLISTVERSION_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetLinkFilterListVersion_Response'] = _CCOMMUNITY_GETLINKFILTERLISTVERSION_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CCommunity_GetLinkFilterHashPrefixes_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetLinkFilterHashPrefixes_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST,
  '__module__' : 'steammessages_linkfilter_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetLinkFilterHashPrefixes_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetLinkFilterHashPrefixes_Request)

CCommunity_GetLinkFilterHashPrefixes_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetLinkFilterHashPrefixes_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETLINKFILTERHASHPREFIXES_RESPONSE,
  '__module__' : 'steammessages_linkfilter_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetLinkFilterHashPrefixes_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetLinkFilterHashPrefixes_Response)

CCommunity_GetLinkFilterHashes_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetLinkFilterHashes_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETLINKFILTERHASHES_REQUEST,
  '__module__' : 'steammessages_linkfilter_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetLinkFilterHashes_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetLinkFilterHashes_Request)

CCommunity_GetLinkFilterHashes_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetLinkFilterHashes_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETLINKFILTERHASHES_RESPONSE,
  '__module__' : 'steammessages_linkfilter_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetLinkFilterHashes_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetLinkFilterHashes_Response)

CCommunity_GetLinkFilterListVersion_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetLinkFilterListVersion_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETLINKFILTERLISTVERSION_REQUEST,
  '__module__' : 'steammessages_linkfilter_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetLinkFilterListVersion_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetLinkFilterListVersion_Request)

CCommunity_GetLinkFilterListVersion_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetLinkFilterListVersion_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETLINKFILTERLISTVERSION_RESPONSE,
  '__module__' : 'steammessages_linkfilter_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetLinkFilterListVersion_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetLinkFilterListVersion_Response)


DESCRIPTOR._options = None
_CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST.fields_by_name['hit_type']._options = None
_CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST.fields_by_name['count']._options = None
_CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST.fields_by_name['start']._options = None
_CCOMMUNITY_GETLINKFILTERHASHPREFIXES_RESPONSE.fields_by_name['hash_prefixes']._options = None
_CCOMMUNITY_GETLINKFILTERHASHES_REQUEST.fields_by_name['hit_type']._options = None
_CCOMMUNITY_GETLINKFILTERHASHES_REQUEST.fields_by_name['count']._options = None
_CCOMMUNITY_GETLINKFILTERHASHES_REQUEST.fields_by_name['start']._options = None
_CCOMMUNITY_GETLINKFILTERHASHES_RESPONSE.fields_by_name['hashes']._options = None
_CCOMMUNITY_GETLINKFILTERLISTVERSION_REQUEST.fields_by_name['hit_type']._options = None
_CCOMMUNITY_GETLINKFILTERLISTVERSION_RESPONSE.fields_by_name['version']._options = None
_CCOMMUNITY_GETLINKFILTERLISTVERSION_RESPONSE.fields_by_name['count']._options = None

_COMMUNITYLINKFILTER = _descriptor.ServiceDescriptor(
  name='CommunityLinkFilter',
  full_name='CommunityLinkFilter',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030JA service for recording data about Steam Community phishing link filtering',
  create_key=_descriptor._internal_create_key,
  serialized_start=1215,
  serialized_end=1925,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLinkFilterHashPrefixes',
    full_name='CommunityLinkFilter.GetLinkFilterHashPrefixes',
    index=0,
    containing_service=None,
    input_type=_CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST,
    output_type=_CCOMMUNITY_GETLINKFILTERHASHPREFIXES_RESPONSE,
    serialized_options=b'\202\265\030RGet a list of hash prefixes for the specified hit type, to use for client caching.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLinkFilterHashes',
    full_name='CommunityLinkFilter.GetLinkFilterHashes',
    index=1,
    containing_service=None,
    input_type=_CCOMMUNITY_GETLINKFILTERHASHES_REQUEST,
    output_type=_CCOMMUNITY_GETLINKFILTERHASHES_RESPONSE,
    serialized_options=b'\202\265\030KGet a list of hashes for the specified hit type, to use for client caching.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLinkFilterListVersion',
    full_name='CommunityLinkFilter.GetLinkFilterListVersion',
    index=2,
    containing_service=None,
    input_type=_CCOMMUNITY_GETLINKFILTERLISTVERSION_REQUEST,
    output_type=_CCOMMUNITY_GETLINKFILTERLISTVERSION_RESPONSE,
    serialized_options=b'\202\265\030PGet a list of hashes describing the version of each chunk of the requested size.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMUNITYLINKFILTER)

DESCRIPTOR.services_by_name['CommunityLinkFilter'] = _COMMUNITYLINKFILTER

CommunityLinkFilter = service_reflection.GeneratedServiceType('CommunityLinkFilter', (_service.Service,), dict(
  DESCRIPTOR = _COMMUNITYLINKFILTER,
  __module__ = 'steammessages_linkfilter_pb2'
  ))

CommunityLinkFilter_Stub = service_reflection.GeneratedServiceStubType('CommunityLinkFilter_Stub', (CommunityLinkFilter,), dict(
  DESCRIPTOR = _COMMUNITYLINKFILTER,
  __module__ = 'steammessages_linkfilter_pb2'
  ))


# @@protoc_insertion_point(module_scope)
